@@ -1,16 +1,20 @@
 package Pod::Weaver::Role::Plugin;
-our $VERSION = '2.001';
+our $VERSION = '3.092970';
+
 
 use Moose::Role;
 # ABSTRACT: a Pod::Weaver plugin
 
+use namespace::autoclean;
+
+
 has plugin_name => (
   is  => 'ro',
   isa => 'Str',
   required => 1,
-  init_arg => '=name',
 );
 
+
 has weaver => (
   is  => 'ro',
   isa => 'Pod::Weaver',
@@ -19,11 +23,9 @@ has weaver => (
   handles  => [ qw(log) ],
 );
 
-no Moose::Role;
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -32,19 +34,38 @@ Pod::Weaver::Role::Plugin - a Pod::Weaver plugin
 
 =head1 VERSION
 
-version 2.001
+version 3.092970
+
+=head1 IMPLEMENTING
+
+This is the most basic role that all plugins must perform.
+
+=head1 ATTRIBUTES
+
+=head2 plugin_name
+
+This name must be unique among all other plugins loaded into a weaver.  In
+general, this will be set up by the configuration reader.
+
+=cut
+
+=pod
+
+=head2 weaver
+
+This is the Pod::Weaver object into which the plugin was loaded.  In general,
+this will be set up when the weaver is instantiated from config.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
